﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Input;
using Hardcodet.Wpf.Util;

namespace Hardcodet.LiveWriter.ApplyCssPlugin
{
  /// <summary>
  /// Interaction logic for ClassBrowser.xaml
  /// </summary>
  public partial class ClassBrowser : Popup
  {
    private readonly PluginSettings settings;
    public string ClassName { get; set; }


    public ClassBrowser(PluginSettings settings)
    {
      this.settings = settings;
      InitializeComponent();

      DataContext = settings;
    }

    public ClassBrowser()
    {
      InitializeComponent();

      mruList.ItemsSource = new[] {"foo", "bar"};
      classList.ItemsSource = new[] {"foo", "bar", "foobar"};

      //hide mru list, if there's just a few classes
      mruList.Visibility = Visibility.Collapsed;
    }


    /// <summary>
    /// Resolves the double-clicked item.
    /// </summary>
    private void OnListBoxDoubleClick(object sender, MouseButtonEventArgs e)
    {
      ListBox lb = (ListBox) sender;

      //get the clicked item under the mouse
      Point pos = e.GetPosition(lb);
      ListBoxItem item = TreeHelper.TryFindFromPoint<ListBoxItem>(lb, pos);
      if (item == null) return;

      if (lb.SelectedItems.Count == 1)
      {
        ClassName = (string) lb.SelectedItems[0];

        //close the popup
        IsOpen = false;
      }
    }


    /// <summary>
    /// 
    /// </summary>
    private void ShowOptions(object sender, RoutedEventArgs e)
    {
      var dlg = new SettingsDialog(settings);
      dlg.ShowDialog();
    }

    private void OnOpened(object sender, System.EventArgs e)
    {
      //hide mru list, if there's just a few classes
      mruList.Visibility = settings == null || settings.ClassNames.Count < 10
                               ? Visibility.Collapsed
                               : Visibility.Visible;
    }
  }
}