using System.Windows.Forms;
using System.Windows.Forms.Integration;
using System.Windows.Interop;
using WindowsLive.Writer.Api;
using IWin32Window=System.Windows.Forms.IWin32Window;

namespace Hardcodet.LiveWriter.ApplyCssPlugin
{
  [WriterPlugin("AF289D86-EBD8-4ae7-9132-D3CE6052DAFE",
      "Apply CSS Class",
      ImagePath = "css.png",
      HasEditableOptions = true,
      PublisherUrl = "http://www.hardcodet.net",
      Description = "Inserts a CSS class statement to the selected content.")]
  [InsertableContentSource("CSS Format...", SidebarText = "CSS Format...")]
  public class Plugin : ContentSource
  {
    /// <summary>
    /// Contains the plugin's settings.
    /// </summary>
    public PluginSettings Settings { get; set; }


    /// <summary>
    /// Initializes the plug-in with the currently stored
    /// plug-in settings.
    /// </summary>
    /// <param name="pluginOptions">Stored plug-in settings.</param>
    public override void Initialize(IProperties pluginOptions)
    {
      base.Initialize(pluginOptions);
      Settings = new PluginSettings(pluginOptions);
    }


    /// <summary>
    /// Shows the class list and assigns the updated markup to the
    /// <paramref name="content"/> variable.
    /// </summary>
    public override DialogResult CreateContent(IWin32Window dialogOwner, ref string content)
    {
      Cursor.Current = Cursors.WaitCursor;

      string className = PopupManager.RequestClassName(Settings);
      if (string.IsNullOrEmpty(className))
      {
        return DialogResult.Cancel;
      }

      //remember item
      Settings.UpdateMruList(className);

      //parse and update HTML
      bool result = ContentParser.InjectClassAttribute(ref content, className);
      return result ? DialogResult.OK : DialogResult.Cancel;
    }


    /// <summary>
    /// Displays the settings dialog.
    /// </summary>
    public override void EditOptions(IWin32Window dialogOwner)
    {
      Cursor.Current = Cursors.WaitCursor;
      var dlg = new SettingsDialog(Settings);

      //make sure keyboard input is properly received in WPF
      ElementHost.EnableModelessKeyboardInterop(dlg);
      Cursor.Current = Cursors.Default;

      //revert to Win interop in order to set the dialog's parent
      WindowInteropHelper helper = new WindowInteropHelper(dlg);
      helper.Owner = dialogOwner.Handle;

      dlg.ShowDialog();
    }
  }
}