﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Shapes;
using Microsoft.Win32;

namespace Hardcodet.LiveWriter.ApplyCssPlugin
{
  /// <summary>
  /// Interaction logic for SettingsDialog.xaml
  /// </summary>
  public partial class SettingsDialog : Window
  {
    private readonly PluginSettings settings;

    public SettingsDialog(PluginSettings settings)
    {
      this.settings = settings;
      InitializeComponent();
      DataContext = settings;
    }

    public SettingsDialog()
    {
      InitializeComponent();
    }


    /// <summary>
    /// Checks whether the Enter key was pressed on the
    /// textbox, and updates the settings accordingly.
    /// </summary>
    private void AddClassName(object sender, KeyEventArgs e)
    {
      if (txtNewItem.Text != String.Empty && e.Key == Key.Return)
      {
        //store new class name
        settings.AddClass(txtNewItem.Text);

        //reset text box
        txtNewItem.Text = String.Empty;
        e.Handled = true;
      }

    }


    /// <summary>
    /// Runs the CSS import.
    /// </summary>
    private void ImportStyles(object sender, RoutedEventArgs e)
    {
      List<string> classNames;
      bool status = ContentParser.TryGetClassNames(out classNames);
      if (status)
      {
        classNames.ForEach(name => settings.AddClass(name));
      }
      
    }


    /// <summary>
    /// Deletes the currently selected entry.
    /// </summary>
    private void DeleteSelectedItem(object sender, KeyEventArgs e)
    {
      if (e.Key == Key.Delete)
      {
        var classNames = lstClassNames.SelectedItems.Cast<string>().ToArray();
        foreach (string className in classNames)
        {
          settings.RemoveClass(className);
        }
      }
    }
  }
}
