﻿using System;
using System.IO;
using System.Windows.Forms;
using System.Xml;


namespace Hardcodet.LiveWriter.QuickClassInsert
{
  public static class ContentParser
  {
    public static bool InjectClassAttribute(ref string content, string className)
    {
      //get clean XHTML content, first (this might mess up the markup if the
      //user selected half a paragraph including the end or start tag of the
      //paragraph
      var htmlDoc = new HtmlAgilityPack.HtmlDocument();
      htmlDoc.LoadHtml(content);
      StringWriter w = new StringWriter();
      htmlDoc.Save(w);
      content = w.ToString();


      XmlDocument doc = new XmlDocument();

      try
      {
        doc.LoadXml(content);
      }
      catch
      {
        //put markup that contains block elements into div tags, inline
        //into spans
        //-> if junk of text was selected that does only contain an opening
        //or closing tag, we'll end up with malformed XHTML
        bool containsBlockElements = ContainsBlockElements(content);
        string tag = containsBlockElements ? "div" : "span";

        string xml = String.Format("<{0}>{1}</{0}>", tag, content);
        try
        {
          doc.LoadXml(xml);
        }
        catch (Exception e)
        {
          string msg = "Could not parse content {0}: {1}";
          MessageBox.Show(String.Format(msg, content, e.Message));
          return false;
        }
      }

      //set the class attribute and return the updated markup
      doc.DocumentElement.SetAttribute("class", className);
      content = doc.DocumentElement.OuterXml;
      return true;
    }


    /// <summary>
    /// Checks whether the submitted markup contains block elements or not.
    /// </summary>
    /// <param name="content"></param>
    /// <returns></returns>
    private static bool ContainsBlockElements(string content)
    {
      content = content.Replace(" ", "");
      return content.Contains("<div")
             || content.Contains("<p")
             || content.Contains("<pre")
             || content.Contains("<center ")
             || content.Contains("<blockquote ")
             || content.Contains("<hr ")
             || content.Contains("<table")
             || content.Contains("<h1")
             || content.Contains("<h2")
             || content.Contains("<h3")
             || content.Contains("<h4")
             || content.Contains("<h5")
             || content.Contains("<h6");
    }
  }
}