﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Windows.Forms;
using WindowsLive.Writer.Api;

namespace Hardcodet.LiveWriter.QuickClassInsert
{

  [WriterPlugin("744A40A1-F433-4c60-BA00-96CD505557DE",
      "Quick CSS Class",
      ImagePath = "css.png",
      HasEditableOptions = true,
      PublisherUrl = "http://www.hardcodet.net",
      Description = "Quickly formats selected content with a predefined CSS class.")]
  [InsertableContentSource("Quick CSS", SidebarText = "Quick CSS.")]
  public class Plugin : ContentSource
  {
    public IProperties PluginSettings { get; private set; }

    
    public string ClassName
    {
      get { return PluginSettings.GetString("ClassName", ""); }
      set { PluginSettings.SetString("ClassName", value); }
    }


    public override void Initialize(IProperties settings)
    {
      base.Initialize(settings);
      PluginSettings = settings;
    }

    public override DialogResult CreateContent(IWin32Window dialogOwner, ref string content)
    {
      //if there is no class configured yet, show options dialog
      if (String.IsNullOrEmpty(ClassName))
      {
        EditOptions(dialogOwner);

        //if the user aborted or didn't set a class,
        //there's nothing to format - cancel
        if (String.IsNullOrEmpty(ClassName))
        {
          return DialogResult.Cancel;
        }
      }
      
      //parse and update HTML
      bool result = ContentParser.InjectClassAttribute(ref content, ClassName);
      return result ? DialogResult.OK : DialogResult.Cancel;
    }


    public override void EditOptions(IWin32Window dialogOwner)
    {
      ClassDefinitionDialog dlg = new ClassDefinitionDialog();
      dlg.ClassName = ClassName;

      var result = dlg.ShowDialog(dialogOwner);

      if (result == DialogResult.OK)
      {
        //store settings
        ClassName = dlg.ClassName;
      }
    }

  }
}
